@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -12,14 +12,12 @@ var _             = require('lodash'),
     utils         = require('../../utils'),
     command       = require('../../command');
 
-var FLOG_VERSION = '4.4.0';
-
 command.Command.definitions.addDefinition('flog', {
   cmd: 'flog',
   args: ['-a'],
   installCheck: function() {
     this.verifyExecutable('ruby', 'Cannot find the ruby commmand.');
-    this.verifyPackage('gem list flog -i -v ' + FLOG_VERSION, 'true', 'Missing "flog" gem, version ' + FLOG_VERSION);
+    this.verifyPackage('gem list flog -i', 'true', 'Missing "flog" gem');
   }
 });
 
