@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -21,8 +21,8 @@ module.exports.configure = function(configuration, params) {
     var context = new TaskContext(configuration, parameters);
     var taskDefinitions = new TaskDefinitions(context);
     var helpers = taskHelpers(context);
-    _.each(glob.sync('./tasks/*.js', { cwd: __dirname }), function(taskPath) {
-      require(taskPath)(taskDefinitions, context, helpers);
+    _.each(glob.sync('./tasks/**/*_tasks.js', { cwd: __dirname }), function(taskPath) {
+      require(taskPath)(taskDefinitions, context, helpers).tasks();
     });
 
     mkdirp.sync(context.tempDir);
