@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -8,6 +8,7 @@
 var _                 = require('lodash'),
     Path              = require('path'),
     glob              = require('glob'),
+    minimatch         = require('minimatch'),
     repositoryPath    = require('./repository_path'),
     languages         = require('./language_definitions'),
     CFValidationError = require('./validation_error'),
@@ -29,11 +30,12 @@ module.exports = function(config) {
   var allFiles;
   var rootPath = configuration.rootPath;
 
-  var collectAllFiles = function(rootPath, includePaths, excludePaths) {
-    var absoluteGlobPaths = repositoryPath.normalise(rootPath, includePaths);
-    var absoluteExcludeGlobPaths = repositoryPath.normalise(rootPath, excludePaths);
+  var absoluteIncludeGlobPaths = repositoryPath.normalise(rootPath, configuration.includePaths);
+  var absoluteExcludeGlobPaths = repositoryPath.normalise(rootPath, configuration.excludePaths);
+
+  var collectAllFiles = function() {
     var allAbsoluteFilenames = _.difference(
-      repositoryPath.expand(absoluteGlobPaths, glob.sync),
+      repositoryPath.expand(absoluteIncludeGlobPaths, glob.sync),
       repositoryPath.expand(absoluteExcludeGlobPaths, glob.sync)
     );
 
@@ -54,6 +56,22 @@ module.exports = function(config) {
   };
 
   this.isValidPath = function(path) {
+    var actualPath = path;
+    if (!Path.isAbsolute(path)) {
+      actualPath = Path.join(rootPath, path);
+    }
+    var isIncluded = _.some(absoluteIncludeGlobPaths, function(globPath) {
+      return minimatch(actualPath, globPath);
+    });
+
+    var isExcluded = _.some(absoluteExcludeGlobPaths, function(globPath) {
+      return minimatch(actualPath, globPath);
+    });
+
+    return isIncluded && !isExcluded;
+  };
+
+  this.fileExists = function(path) {
     return _.find(this.allFiles(), function(f) {
       return f.relativePath === path;
     }) !== undefined;
