@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -30,10 +30,26 @@ var TaskDefinitions = function(context) {
   };
 
   var registerTask = function(task, TaskRunner) {
-    gulp.task.call(gulp, task.name, task.dependencies, function() {
-      task.validateParameters(context.parameters);
-      return new TaskRunner(task, context).run(_.toArray(arguments));
-    });
+    var parametersValidation, taskRun;
+
+    if (task.parameters.length > 0) {
+      parametersValidation = function(done) {
+        task.validateParameters(context.parameters);
+        done();
+      };
+    }
+    if (task.run) {
+      taskRun = new TaskRunner(task, context).run;
+    }
+
+    var taskFns = _.compact([parametersValidation, task.dependency, taskRun]);
+    if (taskFns.length > 1) {
+      gulp.task(task.name, gulp.series.apply(gulp, taskFns));
+    } else {
+      gulp.task(task.name, taskFns.pop());
+    }
+
+    gulp.task(task.name).description = task.description;
   };
 
   var findTask = function(taskName) {
