@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -16,18 +16,7 @@ var _         = require('lodash'),
     appConfig = require('../runtime/app_config');
 
 module.exports = function(taskDef, context, helpers) {
-  var listTasks = function(tasks, title) {
-    var maxTaskNameLength = _.maxBy(tasks, function(t) { return t.name.length; }).name.length;
-    var outputLines = [chalk.yellow("\n" + title)];
-    _.each(tasks, function(task) {
-      outputLines.push(['*', chalk.cyan(_.padEnd(task.name, maxTaskNameLength)) + ':', task.description].join(' '));
-    });
-    logger.log(outputLines.join("\n"));
-  };
-
-  taskDef.addTask('generate-layer-grouping-file', {
-    parameters: [{ name: 'layerGroup' }]
-  }, function() {
+  var generateLayerGroupingFile = function() {
     del.sync(helpers.files.layerGrouping());
     if (context.layerGrouping.isEmpty()) {
       logger.warn('No layer group parameter specified. No grouping file created.');
@@ -37,26 +26,18 @@ module.exports = function(taskDef, context, helpers) {
     .then(function() {
       logger.info('Created: ', helpers.files.layerGrouping());
     });
-  });
+  };
 
-  taskDef.addTask('webserver', { description: 'Start local http server to display graphs' }, function() {
-    var script = Path.resolve(Path.join(appConfig.get('basedir'), 'scripts/webserver.js'));
-    child.execFileSync(script, ['-p', appConfig.get('serverPort'), '-d', context.outputDir], { stdio: 'inherit' });
-  });
+  var listTasks = function(tasks, title) {
+    var maxTaskNameLength = _.maxBy(tasks, function(t) { return t.name.length; }).name.length;
+    var outputLines = [chalk.yellow("\n" + title)];
+    _.each(tasks, function(task) {
+      outputLines.push(['*', chalk.cyan(_.padEnd(task.name, maxTaskNameLength)) + ':', task.description].join(' '));
+    });
+    logger.log(outputLines.join("\n"));
+  };
 
-  taskDef.addTask('clean', { description: 'Delete all analysis reports and files' }, function() {
-    return del([context.tempDir + '/*', context.outputDir + '/*']);
-  });
-
-  taskDef.addTask('list-analysis-tasks', { description: 'List all available analysis tasks' }, function() {
-    listTasks(taskDef.analysisTasks(), 'Analysis tasks');
-  });
-
-  taskDef.addTask('help',
-    {
-      description: 'List all tasks or show help on a particular task',
-      parameters: [{ name: 'taskName' }]
-    }, function() {
+  var printHelp = function(done) {
     if (_.isEmpty(context.parameters.taskName)) {
       listTasks(taskDef.allTasks(), 'All tasks');
     } else {
@@ -66,7 +47,40 @@ module.exports = function(taskDef, context, helpers) {
         chalk.yellow('Usage') + ': ' + task.usage
       ].join("\n"));
     }
-  });
+    done();
+  };
 
-  taskDef.addTask('default', ['help']);
+  var listAnalysisTasks = function(done) {
+    listTasks(taskDef.analysisTasks(), 'Analysis tasks');
+    done();
+  };
+
+  return {
+    functions: {
+      generateLayerGroupingFile: generateLayerGroupingFile
+    },
+    tasks: function() {
+      taskDef.addTask('generate-layer-grouping-file', { parameters: [{ name: 'layerGroup' }] },
+        generateLayerGroupingFile);
+
+      taskDef.addTask('webserver', { description: 'Start local http server to display graphs' }, function() {
+        var script = Path.resolve(Path.join(appConfig.get('basedir'), 'scripts/webserver.js'));
+        child.execFileSync(script, ['-p', appConfig.get('serverPort'), '-d', context.outputDir], { stdio: 'inherit' });
+      });
+
+      taskDef.addTask('clean', { description: 'Delete all analysis reports and files' }, function() {
+        return del([context.tempDir + '/*', context.outputDir + '/*']);
+      });
+
+      taskDef.addTask('list-analysis-tasks', { description: 'List all available analysis tasks' }, listAnalysisTasks);
+
+      taskDef.addTask('help',
+        {
+          description: 'List all tasks or show help on a particular task',
+          parameters: [{ name: 'taskName' }]
+        }, printHelp);
+
+      taskDef.addTask('default', listAnalysisTasks);
+    }
+  };
 };
