@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -18,7 +18,7 @@ var appendChildElement = function(parentElement, childElement) {
 
 module.exports = {
   createHtmlElement: function(htmlTag, parent) {
-    return _.tap(d3.select(document.createElement(htmlTag)), function(htmlElement) {
+    return _.tap(d3.create(htmlTag), function(htmlElement) {
       appendChildElement(parent, htmlElement);
     });
   },
