@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -21,6 +21,9 @@ module.exports = function(options) {
   };
 
   this.toSeries = Bluebird.method(function(data) {
+    if (_.isEmpty(data.children)) {
+      return null;
+    }
     normaliseData(data);
 
     var rootNode = d3.hierarchy(data);
