@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -24,7 +24,7 @@ module.exports = function(id, diagramSettings) {
   this.onData = function(data) {
     var self = this;
     dataProxy.processData(data).then(function(series) {
-      self.hasData((_.isArray(series) && series.length > 0) || _.isObject(series));
+      self.hasData((!_.isEmpty(series)));
       if (!self.hasData()) { return; }
 
       var model = new diagramSettings.Model(diagramSettings.configuration, series);
