@@ -1,6 +1,6 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
@@ -49,13 +49,12 @@ module.exports = function(options) {
 
     var zoomTransition = new ZoomTransition(options.diameter, allCircles, allLabels);
 
-    allCircles.on('click', function(node) {
-      if (!node.isLeaf()) {
-        var targetNode = model.currentFocus === node ? model.rootNode : node;
-        var transition = zoomTransition.start(model.currentFocus, targetNode);
-        model.currentFocus = targetNode;
-        transition.on('end', mainChart.updateComponents.bind(mainChart));
-      }
+    allCircles.filter(function(d) { return !d.isLeaf(); })
+    .on('click', function(node) {
+      var targetNode = model.currentFocus === node ? model.rootNode : node;
+      var transition = zoomTransition.start(model.currentFocus, targetNode);
+      model.currentFocus = targetNode;
+      transition.on('end', mainChart.updateComponents.bind(mainChart));
       d3.event.stopPropagation();
     });
     zoomTransition.zoomToNode(model.rootNode);
