@@ -1,11 +1,12 @@
 /*
  * code-forensics
- * Copyright (C) 2016-2017 Silvio Montanari
+ * Copyright (C) 2016-2018 Silvio Montanari
  * Distributed under the GNU General Public License v3.0
  * see http://www.gnu.org/licenses/gpl.html
  */
 
 var d3       = require('d3'),
+    _        = require('lodash'),
     Bluebird = require('bluebird');
 
 module.exports = function(options) {
@@ -15,6 +16,9 @@ module.exports = function(options) {
 
 
   this.toSeries = Bluebird.method(function(data) {
+    if (_.isEmpty(data.children)) {
+      return null;
+    }
     var rootNode = d3.hierarchy(data).sum(function(node) {
       return node[options.valueProperty];
     });
